summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorhobbs <hobbs>2003-04-18 21:56:59 (GMT)
committerhobbs <hobbs>2003-04-18 21:56:59 (GMT)
commite3eb5cec164d8293d8804240893f09ba9c44096f (patch)
tree094a5d81e814e684cd85fddba7497025f2f8f31b
parent742abd221a0f7d0cefe9d5707d3216c9413ea72e (diff)
downloadtk-e3eb5cec164d8293d8804240893f09ba9c44096f.zip
tk-e3eb5cec164d8293d8804240893f09ba9c44096f.tar.gz
tk-e3eb5cec164d8293d8804240893f09ba9c44096f.tar.bz2
* generic/tkCursor.c: s/GetCursor/TkcGetCursor as Windows has a
GetCursor func already, which causes compiler warnings.
-rw-r--r--generic/tkCursor.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/generic/tkCursor.c b/generic/tkCursor.c
index ce6b381..4fde82f 100644
--- a/generic/tkCursor.c
+++ b/generic/tkCursor.c
@@ -11,7 +11,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tkCursor.c,v 1.9 2002/08/05 04:30:38 dgp Exp $
+ * RCS: @(#) $Id: tkCursor.c,v 1.9.2.1 2003/04/18 21:56:59 hobbs Exp $
*/
#include "tkPort.h"
@@ -44,7 +44,7 @@ static void DupCursorObjProc _ANSI_ARGS_((Tcl_Obj *srcObjPtr,
Tcl_Obj *dupObjPtr));
static void FreeCursor _ANSI_ARGS_((TkCursor *cursorPtr));
static void FreeCursorObjProc _ANSI_ARGS_((Tcl_Obj *objPtr));
-static TkCursor * GetCursor _ANSI_ARGS_((Tcl_Interp *interp,
+static TkCursor * TkcGetCursor _ANSI_ARGS_((Tcl_Interp *interp,
Tk_Window tkwin, CONST char *name));
static TkCursor * GetCursorFromObj _ANSI_ARGS_((Tk_Window tkwin,
Tcl_Obj *objPtr));
@@ -147,10 +147,10 @@ Tk_AllocCursorFromObj(interp, tkwin, objPtr)
}
/*
* Still no luck. Call GetCursor to allocate a new TkCursor object.
*/
- cursorPtr = GetCursor(interp, tkwin, Tcl_GetString(objPtr));
+ cursorPtr = TkcGetCursor(interp, tkwin, Tcl_GetString(objPtr));
objPtr->internalRep.twoPtrValue.ptr1 = (VOID *) cursorPtr;
if (cursorPtr == NULL) {
return None;
@@ -192,7 +192,7 @@ Tk_GetCursor(interp, tkwin, string)
Tk_Uid string; /* Description of cursor. See manual entry
* for details on legal syntax. */
{
- TkCursor *cursorPtr = GetCursor(interp, tkwin, string);
+ TkCursor *cursorPtr = TkcGetCursor(interp, tkwin, string);
if (cursorPtr == NULL) {
return None;
}
@@ -202,7 +202,7 @@ Tk_GetCursor(interp, tkwin, string)
/*
*----------------------------------------------------------------------
*
- * GetCursor --
+ * TkcGetCursor --
*
* Given a string describing a cursor, locate (or create if necessary)
* a cursor that fits the description. This routine returns the
@@ -227,7 +227,7 @@ Tk_GetCursor(interp, tkwin, string)
*/
static TkCursor *
-GetCursor(interp, tkwin, string)
+TkcGetCursor(interp, tkwin, string)
Tcl_Interp *interp; /* Interpreter to use for error reporting. */
Tk_Window tkwin; /* Window in which cursor will be used. */
CONST char *string; /* Description of cursor. See manual entry
@@ -147,10 +147,10 @@ Tk_AllocCursorFromObj(interp, tkwin, objPtr)
}
/*
- * Still no luck. Call GetCursor to allocate a new TkCursor object.
+ * Still no luck. Call TkcGetCursor to allocate a new TkCursor object.
*/